/*
 * Segment 2 (KEx), SWE LMS-TIC3
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.kex.lmstic3.vew.daten;

import java.util.List;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import de.bsvrz.kex.lmstic3.vew.daten.tic.TIC3Exception;
import de.bsvrz.kex.lmstic3.vew.daten.tic.elemente.TIC3Zeitstempel;
import de.bsvrz.kex.lmstic3.vew.daten.tmc.TMCEvent;
import de.bsvrz.kex.lmstic3.vew.daten.tmc.TMCKoordinate;
import de.bsvrz.kex.lmstic3.vew.daten.tmc.TMCLocation;
import de.bsvrz.kex.lmstic3.vew.daten.tmc.TMCPrioritaet.TMCPrioritaetEnum;
import de.bsvrz.kex.lmstic3.vew.daten.tmc.TMCStatus.TMCStatusEnum;

/**
 * Interface externe Meldungsdaten.
 *
 * @author BitCtrl Systems GmbH, Gieseler
 * @version $Id$
 */

public interface ExterneMeldungsDaten {

	String getDatenProduzent();

	void setDatenProduzent(final String produzent);

	String getDatenKennung();

	void setDatenKennung(final String kennung);

	String getEreignisBeschreibung();

	void setEreignisBeschreibung(final String beschreibung);

	String getID();

	void setID(final String id);

	/**
	 * Gibt den Zeitpunkt der Datenerzeugung der Meldung zur&uuml;ck.
	 * 
	 * @return {@link TIC3Zeitstempel}
	 */
	TIC3Zeitstempel getDatenErzeugungsZeit();

	void setDatenErzeugungsZeit(final Long zeitStempel);

	/**
	 * Gibt den Zeitpunkt der letzten Aktualisierung der Meldungsdaten
	 * zur&uuml;ck.
	 * 
	 * @return {@link TIC3Zeitstempel}
	 */
	TIC3Zeitstempel getDatenAktualisierungsZeit();

	void setDatenAktualisierungsZeit(final Long zeitStempel);

	/**
	 * Gibt den Zeitpunkt des Beginns des Ereignisses zur&uuml;ck.
	 * 
	 * @return {@link TIC3Zeitstempel}
	 */
	TIC3Zeitstempel getDatenStartZeit();

	void setDatenStartZeit(final Long zeitStempel);

	/**
	 * Gibt den Zeitpunkt des Endes des Ereignisses zur&uuml;ck.
	 * 
	 * @return {@link TIC3Zeitstempel}
	 */
	TIC3Zeitstempel getDatenEndeZeit();

	void setDatenEndeZeit(final Long zeitStempel);

	/**
	 * Gibt den Status der Meldung zur&uuml;ck.
	 * 
	 * @return {@link TMCStatusEnum}
	 */
	TMCStatusEnum getTMCMeldungsStatus();

	void setTMCMeldungsStatus(final TMCStatusEnum stat) throws TIC3Exception;

	/**
	 * Gibt die Priorit&auml;t der Meldung zur&uuml;ck.
	 * 
	 * @return {@link TMCPrioritaetEnum}
	 */
	TMCPrioritaetEnum getTMCMeldungsPrioritaet();

	void setTMCMeldungsPrioritaet(final TMCPrioritaetEnum prio) throws TIC3Exception;

	/**
	 * Gibt die Information zur&uuml;ck, ob es sich um ein Ereignis in beiden
	 * Richtungen handelt.
	 * 
	 * @return <code>true</code>, wenn in beiden Richtungen, sonst
	 *         <code>false</code>
	 */
	boolean istEreignisInBeidenRichtungen();

	/**
	 * Gibt die Ereignisse der Meldung zur&uuml;ck.
	 * 
	 * @return Liste von {@link TMCEvent}
	 */
	List<TMCEvent> getTMCEreignisse();

	void setTMCEreignisse(final List<TMCEvent> ereignisse) throws TIC3Exception;

	/**
	 * Gibt die TMC-Lokationsinformationen der Meldung zur&uuml;ck.
	 * 
	 * @return Liste von {@link TMCLocation}
	 */
	List<TMCLocation> getTMCLokationen();

	void setTMCLokationen(final List<TMCLocation> lokationen);

	/**
	 * Gibt die Koordinaten der Meldung zur&uuml;ck.
	 * 
	 * @return Liste von {@link TMCKoordinate}
	 */
	List<TMCKoordinate> getKoordinaten();

	/**
	 * Erzeugt eine PID aus den Daten der Meldung.
	 *
	 * @return PID
	 */
	String bildePid();

	Element erzeugeDocumentElement(Document doc, Element root) throws TIC3Exception;
}
