/*
 * Segment 2 (KEx), SWE LMS-TIC3
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.kex.lmstic3.vew.daten.tic.elemente;

import java.util.ArrayList;
import java.util.List;

import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.dav.daf.main.Data.Array;
import de.bsvrz.kex.lmstic3.vew.LMSParameter;
import de.bsvrz.kex.lmstic3.vew.daten.tic.AbstractTIC3InfoElement;
import de.bsvrz.kex.lmstic3.vew.daten.tic.KoordinatenReduktion;
import de.bsvrz.kex.lmstic3.vew.daten.tic.TIC3Exception;
import de.bsvrz.kex.lmstic3.vew.daten.tic.TIC3InfoElement;

/**
 * TIC3-Lokationsinformationen mit WGS-Koordinaten.
 * 
 * <p>
 * Entspricht TIC3 Info Typ 'ShapeType'.
 * </p>
 *
 * @author BitCtrl Systems GmbH, Gieseler
 * @version $Id$
 */
public class TIC3ShapeType extends AbstractTIC3InfoElement {

	private TIC3LocationTyp locationTyp = new TIC3LocationTyp();

	private List<TIC3Koordinaten> koordinaten = new ArrayList<>();

	/**
	 * Erzeugt ein neues Objekt.
	 *
	 * @param xmlName
	 *            Name des XML-ELementes
	 * @param davName
	 *            Name des DAV-Attributes
	 */
	public TIC3ShapeType(final String xmlName, final String davName) {
		super(xmlName, davName);
		addKindElement(locationTyp);
	}

	@Override
	public void publizieren(final Data davdata, final LMSParameter parameter) throws TIC3Exception {
		if (koordinaten.size() > 0) {
			final Data ddata;

			if ((getDavAttributName() != null) && (getDavAttributName().length() > 0)) {
				final Array array = davdata.getArray(getDavAttributName());
				array.setLength(1);
				ddata = array.getItem(0);
			} else {
				ddata = davdata;
			}

			for (final TIC3InfoElement child : getKindElemente()) {
				child.publizieren(ddata, parameter);
			}

			// Koordinatenliste reduzieren
			final List<TIC3Koordinaten> redkoordinaten;
			if (parameter != null) {
				redkoordinaten = KoordinatenReduktion.reduziere(koordinaten, parameter.getKoordinatenRaster());
			} else {
				redkoordinaten = koordinaten;
			}

			final Data.Array array = ddata.getArray(TIC3Koordinaten.DAV_ATTR_KOORDINATE);
			final int anzahl = redkoordinaten.size();
			array.setLength(anzahl);
			for (int i = 0; i < anzahl; i++) {
				redkoordinaten.get(i).publizieren(array.getItem(i), parameter);
			}
		}
	}

	/**
	 * Gibt die Liste der Koordinaten zur&uuml;ck.
	 * 
	 * @return Liste der Koordinaten
	 */
	public List<TIC3Koordinaten> getKoordinaten() {
		return koordinaten;
	}

	@Override
	public void einlesenXML(final Node node) throws TIC3Exception {
		super.einlesenXML(node);
		final NodeList nl = node.getChildNodes();

		for (int i = 0; i < nl.getLength(); i++) {
			final Node n = nl.item(i);
			if (n.getNodeName().equals(TIC3Koordinaten.XML_ELEMENT_KOORDINATE)) {
				final TIC3Koordinaten k = new TIC3Koordinaten();
				k.einlesenXML(n);
				koordinaten.add(k);
			}
		}
	}

	@Override
	public Element erzeugeDocumentElement(final Document doc, final Element parent) throws TIC3Exception {
		// das wird nicht exportiert
		return null;
	}

	@Override
	public String toString() {
		return this.getClass().getSimpleName() + ": " + locationTyp + ", " + koordinaten.size() + " Koordinaten";
	}
}
