/*
 * Segment 2 (KEx), SWE LMS-TIC3
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.kex.lmstic3.vew.daten.tic.elemente;

import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.kex.lmstic3.vew.LMSParameter;
import de.bsvrz.kex.lmstic3.vew.daten.tic.AbstractTIC3InfoElement;
import de.bsvrz.kex.lmstic3.vew.daten.tic.TIC3Exception;
import de.bsvrz.kex.lmstic3.vew.daten.tic.TIC3InfoElement;
import de.bsvrz.kex.lmstic3.vew.daten.tic.TIC3OptionalerDoubleWert;
import de.bsvrz.kex.lmstic3.vew.daten.tic.TMCInteger;

/**
 * TIC3 TmcEventQuantifierType.
 * 
 * <p>
 * TIC3 Info XML Element: Quantifier (QUA), A list of additional quantifiers
 * used in combination with the TMC event code.
 * </p>
 *
 * @author BitCtrl Systems GmbH, Gieseler
 * @version $Id$
 */
public class TIC3TmcQuantifier extends AbstractTIC3InfoElement {

	/**
	 * TIC3 Info XML Element: Quantifier (QUA), A list of additional quantifiers
	 * used in combination with the TMC event code.
	 */
	public static final String XML_ELEMENT_QUANTIFIER = "Quantifier";

	/**
	 * DAV-Attribut.
	 */
	public static final String DAV_ATTR_QUANTIFIER = "Quantifier";

	/**
	 * Erzeugt ein neues Objekt.
	 */
	public TIC3TmcQuantifier() {
		super(XML_ELEMENT_QUANTIFIER, DAV_ATTR_QUANTIFIER);

		/**
		 * Label.
		 * <p>
		 * TIC3 Info XML Element: Label (LBL), The label as defined in the TMC
		 * standard ISO 14819-1.
		 * </p>
		 */
		addKindElement(new TMCInteger("Label", "Label"));

		/**
		 * Number.
		 * <p>
		 * TIC3 Info XML Element: Number (NUM), The number of the quantifier.
		 * </p>
		 */
		addKindElement(new TMCInteger("Number", "Number"));

		/**
		 * Code.
		 * <p>
		 * TIC3 Info XML Element: Code (COD), The quantifier code as defined in
		 * the TMC standard ISO 14819-2.
		 * </p>
		 */
		addKindElement(new TMCInteger("Code", "Code"));

		/**
		 * Wert.
		 * <p>
		 * TIC3 Info XML Element: Value (VAL), The decoded quantifier value.
		 * </p>
		 * <p>
		 * Entgegen dem Schema wurden hier auch double-Werte beobachtet.
		 * </p>
		 */
		addKindElement(new TIC3OptionalerDoubleWert("Value", "Value"));
	}

	@Override
	public void publizieren(final Data davdata, final LMSParameter parameter) throws TIC3Exception {
		setDavDaten(davdata);
		for (final TIC3InfoElement child : getKindElemente()) {
			child.publizieren(davdata, parameter);
		}
	}
}
